/* --------------------------------------------------------------- */
/* mbedDebug.c -- debug device I/O functions                       */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
/* The debug functions communicate with the host computer using a  */
/* serial link.                                                    */
/*                                                                 */
/* For mbed, this is the SerialPC link, which is on UART0.         */
/* Note that on Windows a driver must be installed for this to     */
/* work.  See: http://mbed.org/handbook/SerialPC                   */
/* --------------------------------------------------------------- */

#define  DEBUG_UART 0         // which UART to use

#define  TOLLOS_IO            // allow use of I/O functions
#include "tollos.h"

// In mbed, the debug serial port is UART0, connected through the
// interface processor to the host computer via USB

/* --------------------------------------------------------------- */
/* debugGetcIO -- get character                                    */
/*                                                                 */
/*   returns character read from host, or -1 if none there         */
/*                                                                 */
/* This function does not block.                                   */
/* --------------------------------------------------------------- */
int debugGetcIO(void) {         // get character
  return uartGetcIO(DEBUG_UART);
  } // debugGetcIO

/* --------------------------------------------------------------- */
/* debugInitIO -- initialize port for I/O                          */
/*                                                                 */
/*   baud -- rate to run debug communications                      */
/*                                                                 */
/* It is recommended that a 'standard' baud rate be used, e.g.,    */
/* 9600 or 115200.                                                 */
/*                                                                 */
/* At 9600 about 38 characters can be sent in 40ms (one major      */
/* tick); at 115200, 460 can be sent.                              */
/* --------------------------------------------------------------- */
void debugInitIO(uint baud) {
  uartInitIO(DEBUG_UART, baud);
  } // debugInitIO


/* --------------------------------------------------------------- */
/* debugPutcIO -- send character to debug terminal                 */
/*                                                                 */
/*   ch -- character to send                                       */
/*                                                                 */
/* This waits for any previous send to complete.                   */
/* --------------------------------------------------------------- */
void debugPutcIO(int ch) {      // send character
  uartPutcIO(DEBUG_UART, ch);
  } // debugPutcIO

